==> zio-aws-detective_3-5.17.116.2-sources.jar: zio/aws/detective/model/ListInvitationsResponse.scala <==
package zio.aws.detective.model
import zio.ZIO
import zio.aws.detective.model.primitives.PaginationToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListInvitationsResponse(
    invitations: Option[Iterable[zio.aws.detective.model.MemberDetail]] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.detective.model.ListInvitationsResponse = {
    import ListInvitationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.detective.model.ListInvitationsResponse
      .builder()
      .optionallyWith(
        invitations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.invitations)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.detective.model.ListInvitationsResponse.ReadOnly =
    zio.aws.detective.model.ListInvitationsResponse.wrap(buildAwsValue())
}
object ListInvitationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.detective.model.ListInvitationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.detective.model.ListInvitationsResponse =
      zio.aws.detective.model.ListInvitationsResponse(
        invitations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def invitations: Option[List[zio.aws.detective.model.MemberDetail.ReadOnly]]
    def nextToken: Option[PaginationToken]
    def getInvitations: ZIO[Any, AwsError, List[
      zio.aws.detective.model.MemberDetail.ReadOnly
    ]] = AwsError.unwrapOptionField("invitations", invitations)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.detective.model.ListInvitationsResponse
  ) extends zio.aws.detective.model.ListInvitationsResponse.ReadOnly {
    override val invitations
        : Option[List[zio.aws.detective.model.MemberDetail.ReadOnly]] = scala
      .Option(impl.invitations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.detective.model.MemberDetail.wrap(item)
        }.toList
      )
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.detective.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.detective.model.ListInvitationsResponse
  ): zio.aws.detective.model.ListInvitationsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-detective_3-5.17.257.1-sources.jar: zio/aws/detective/model/ListInvitationsResponse.scala <==
package zio.aws.detective.model
import zio.ZIO
import zio.aws.detective.model.primitives.PaginationToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListInvitationsResponse(
    invitations: Optional[Iterable[zio.aws.detective.model.MemberDetail]] =
      Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.detective.model.ListInvitationsResponse = {
    import ListInvitationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.detective.model.ListInvitationsResponse
      .builder()
      .optionallyWith(
        invitations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.invitations)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.detective.model.ListInvitationsResponse.ReadOnly =
    zio.aws.detective.model.ListInvitationsResponse.wrap(buildAwsValue())
}
object ListInvitationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.detective.model.ListInvitationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.detective.model.ListInvitationsResponse =
      zio.aws.detective.model.ListInvitationsResponse(
        invitations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def invitations
        : Optional[List[zio.aws.detective.model.MemberDetail.ReadOnly]]
    def nextToken: Optional[PaginationToken]
    def getInvitations: ZIO[Any, AwsError, List[
      zio.aws.detective.model.MemberDetail.ReadOnly
    ]] = AwsError.unwrapOptionField("invitations", invitations)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.detective.model.ListInvitationsResponse
  ) extends zio.aws.detective.model.ListInvitationsResponse.ReadOnly {
    override val invitations
        : Optional[List[zio.aws.detective.model.MemberDetail.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.invitations())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.detective.model.MemberDetail.wrap(item)
          }.toList
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.detective.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.detective.model.ListInvitationsResponse
  ): zio.aws.detective.model.ListInvitationsResponse.ReadOnly = new Wrapper(
    impl
  )
}
